==> esup-canal-intranet-1.20-RC-1.zip: db/PostgreSQL.sql <==
CREATE TABLE INT_CLE (
  NOM_TABLE varchar(20) NOT NULL default '',
  CLE int(11) default NULL,
  PRIMARY KEY  (NOM_TABLE)
);


INSERT INTO INT_CLE VALUES ('INT_DOSSIER', 1);


CREATE TABLE INT_DOCUMENT (
  ID_DOC varchar(15) NOT NULL default '0',
  ID_INT varchar(15) NOT NULL default '',
  DES_DOC text,
  TYPE_DOC char(1) default NULL,
  FILE_DOC text,
  AUT_DOC varchar(15) default NULL,
  DATE_DOC varchar(8) default NULL,
  ID_DOS int(11) default NULL,
  LOCK_DOC char(1) default NULL,
  NOM_DOC text NOT NULL,
  EXT_DOC text NOT NULL,
  NEW_DOC char(1) NOT NULL default '',
  ORDER_DOC int(11) default NULL,
  LIMIT_DOC varchar(8) NOT NULL default '',
  PRIMARY KEY  (ID_DOC,ID_INT)
);


CREATE TABLE INT_DOSSIER (
  ID_DOS int(11) NOT NULL default '0',
  ID_INT varchar(15) default NULL,
  ID_PAR int(11) default NULL,
  NOM_DOS text,
  VAL_DOS char(1) default NULL,
  PRIMARY KEY  (ID_DOS)
);


CREATE TABLE INT_INTRANET (
  ID_INT varchar(15) NOT NULL default '',
  NOM_INT text,
  DOC_INT int(15) NOT NULL default '0',
  ID_RES varchar(15) default NULL,
  PRIMARY KEY  (ID_INT)
);


CREATE TABLE INT_MIME (
  EXT_MIME varchar(10) NOT NULL default '',
  TYPE_MIME text NOT NULL,
  PRIMARY KEY  (EXT_MIME)
);


INSERT INTO INT_MIME VALUES ('.doc', 'application/msword');
INSERT INTO INT_MIME VALUES ('.gz', 'application/x-gzip');
INSERT INTO INT_MIME VALUES ('.htm', 'text/html');
INSERT INTO INT_MIME VALUES ('.html', 'text/html');
INSERT INTO INT_MIME VALUES ('.pdf', 'application/pdf');
INSERT INTO INT_MIME VALUES ('.ppt', 'application/mspowerpoint');
INSERT INTO INT_MIME VALUES ('.rar', 'application/rar');
INSERT INTO INT_MIME VALUES ('.tar', 'application/x-tar');
INSERT INTO INT_MIME VALUES ('.txt', 'text/plain');
INSERT INTO INT_MIME VALUES ('.xls', 'application/msexcel');
INSERT INTO INT_MIME VALUES ('.zip', 'application/zip');


CREATE TABLE INT_POPULATION (
  ID_INT varchar(15) NOT NULL default '',
  TYPE_POP char(1) NOT NULL default '',
  ID_POP varchar(240) NOT NULL default '',
  PRIMARY KEY  (ID_INT,TYPE_POP,ID_POP)
);


CREATE TABLE INT_PUBLICATEUR (
  ID_DOS int(11) NOT NULL default '0',
  TYPE_PUB char(1) NOT NULL default '',
  ID_PUB varchar(240) NOT NULL default '',
  PRIMARY KEY  (ID_DOS,TYPE_PUB,ID_PUB)
);


CREATE TABLE INT_SUPERUSER (
  LOGIN varchar(15) NOT NULL default '',
  PRIMARY KEY  (LOGIN)
);


INSERT INTO INT_SUPERUSER VALUES ('admin');


CREATE TABLE INT_VALIDEUR (
  ID_DOS int(11) NOT NULL default '0',
  LOGIN varchar(15) NOT NULL default '',
  NOT_VAL char(1) default NULL,
  PRIMARY KEY  (ID_DOS,LOGIN)
);

==> esup-canal-intranet-2.00-RC-1.zip: db/PostgreSQL.sql <==
CREATE TABLE INT_CLE (
  NOM_TABLE varchar(20) NOT NULL default '',
  CLE integer default NULL,
  PRIMARY KEY  (NOM_TABLE)
);


INSERT INTO INT_CLE VALUES ('INT_DOSSIER', 1);


CREATE TABLE INT_DOCUMENT (
  ID_DOC varchar(15) NOT NULL default '0',
  ID_INT varchar(15) NOT NULL default '',
  DES_DOC text,
  TYPE_DOC char(1) default NULL,
  FILE_DOC text,
  AUT_DOC varchar(15) default NULL,
  DATE_DOC varchar(8) default NULL,
  ID_DOS integer default NULL,
  LOCK_DOC char(1) default NULL,
  NOM_DOC text NOT NULL,
  EXT_DOC text NOT NULL,
  NEW_DOC char(1) NOT NULL default '',
  ORDER_DOC integer default NULL,
  LIMIT_DOC varchar(8) NOT NULL default '',
  PRIMARY KEY  (ID_DOC,ID_INT)
);


CREATE TABLE INT_DOSSIER (
  ID_DOS integer NOT NULL default '0',
  ID_INT varchar(15) default NULL,
  ID_PAR integer default NULL,
  NOM_DOS text,
  VAL_DOS char(1) default NULL,
  PRIMARY KEY  (ID_DOS)
);


CREATE TABLE INT_INTRANET (
  ID_INT varchar(15) NOT NULL default '',
  NOM_INT text,
  DOC_INT integer NOT NULL default '0',
  ID_RES varchar(15) default NULL,
  PRIMARY KEY  (ID_INT)
);


CREATE TABLE INT_MIME (
  EXT_MIME varchar(10) NOT NULL default '',
  TYPE_MIME text NOT NULL,
  PRIMARY KEY  (EXT_MIME)
);


INSERT INTO INT_MIME VALUES ('.doc', 'application/msword');
INSERT INTO INT_MIME VALUES ('.gz', 'application/x-gzip');
INSERT INTO INT_MIME VALUES ('.htm', 'text/html');
INSERT INTO INT_MIME VALUES ('.html', 'text/html');
INSERT INTO INT_MIME VALUES ('.pdf', 'application/pdf');
INSERT INTO INT_MIME VALUES ('.ppt', 'application/mspowerpoint');
INSERT INTO INT_MIME VALUES ('.rar', 'application/rar');
INSERT INTO INT_MIME VALUES ('.tar', 'application/x-tar');
INSERT INTO INT_MIME VALUES ('.txt', 'text/plain');
INSERT INTO INT_MIME VALUES ('.xls', 'application/msexcel');
INSERT INTO INT_MIME VALUES ('.zip', 'application/zip');


CREATE TABLE INT_POPULATION (
  ID_INT varchar(15) NOT NULL default '',
  TYPE_POP char(1) NOT NULL default '',
  ID_POP varchar(240) NOT NULL default '',
  PRIMARY KEY  (ID_INT,TYPE_POP,ID_POP)
);


CREATE TABLE INT_PUBLICATEUR (
  ID_DOS integer NOT NULL default '0',
  TYPE_PUB char(1) NOT NULL default '',
  ID_PUB varchar(240) NOT NULL default '',
  PRIMARY KEY  (ID_DOS,TYPE_PUB,ID_PUB)
);


CREATE TABLE INT_SUPERUSER (
  LOGIN varchar(15) NOT NULL default '',
  PRIMARY KEY  (LOGIN)
);


INSERT INTO INT_SUPERUSER VALUES ('admin');


CREATE TABLE INT_VALIDEUR (
  ID_DOS integer NOT NULL default '0',
  LOGIN varchar(15) NOT NULL default '',
  NOT_VAL char(1) default NULL,
  PRIMARY KEY  (ID_DOS,LOGIN)
);
